@@ -1,7 +1,7 @@
 use Glib::Object::Introspection;
 use Test::More;
 
-unless (-e 'build/libregress.so') {
+unless (-e 'build/libregress.so' && -e 'build/libgimarshallingtests.so') {
   plan skip_all => 'Need the test libraries';
 }
 
@@ -14,7 +14,13 @@ unless (defined $ENV{LD_LIBRARY_PATH} &&
 Glib::Object::Introspection->setup(
   basename => 'Regress',
   version => '1.0',
-  package => 'main',
+  package => 'Regress',
+  search_path => 'build');
+
+Glib::Object::Introspection->setup(
+  basename => 'GIMarshallingTests',
+  version => '1.0',
+  package => 'GI',
   search_path => 'build');
 
 # Inspired by Test::Number::Delta
@@ -23,4 +29,9 @@ sub delta_ok ($$;$) {
   ok (abs ($a - $b) < 1e-6, $msg);
 }
 
+sub check_gi_version {
+  my ($x, $y, $z) = @_;
+  return !system ('pkg-config', "atleast-version=$x.$y.$z");
+}
+
 1;
